De eigenaar van de ingestuurde documenten geeft hierbij toestemming aan de Nederlandse Taalunie (NTU) om zijn/haar documenten te (laten) gebruiken ten behoeve van het Stevin Nederlandstalig Referentie Corpus (SoNaR) dat op dit moment ontwikkeld wordt.

SoNaR wordt een databank met minimaal 500 miljoen hedendaagse Nederlandse woorden lopende tekst die als algemene referentie kan dienen voor allerlei onderzoek naar taal en taalgebruik en voor onderzoek op het gebied van de taal- en spraaktechnologie. Bij het verzamelen van teksten gaat speciale aandacht uit naar taalgebruik in nieuwe media, zoals sms-berichten, e-mail, en chats. De inhoud van de ingestuurde documenten zal in de eerste plaats gebruikt worden om de databank verder te ontwikkelen en aan te vullen. Verder kunnen (delen van) de ingestuurde documenten in SoNaR worden opgenomen om te illustreren op welke manier en in welke context bepaalde woorden gebruikt worden.

In dit verband zal uitsluitend de inhoud van het ingestuurde document worden gebruikt. Persoonsgegevens zullen niet worden gebruikt of op enigerlei wijze openbaar gemaakt worden.

De deelnemer verleent de NTU hierbij, en de NTU accepteert, het recht om (een deel van) de ingestuurde documenten te gebruiken ten behoeve van de ontwikkeling van SoNaR en het recht om (een deel van) de ingestuurde documenten in SoNaR op te nemen en als onderdeel van SoNaR te verveelvoudigen, openbaar te maken, te hergebruiken en te exploiteren, waaronder begrepen a) het recht (sub)licenties aan derden te verlenen voor het gebruik van SoNaR voor onderzoek en onderwijs b) het verwerken en/of incorporeren van SoNaR in andere producten, zoals corpora en corpus query systems, en c) het recht sublicenties aan derden te verlenen voor het gebruiken van SoNaR voor de ontwikkeling van taal- en/of spraaktechnologische eindproducten en het exploiteren van deze nieuwe producten voor commerciële of niet-commerciële doeleinden.

(U wordt bij het invullen van gegevens verzocht om voor Nederlands of Belgisch recht te kiezen):

Voor Nederland:

a) Op deze overeenkomst, welke als wettelijk bewijs geldt, is het Nederlandse recht van toepassing. Geschillen die voortvloeien uit of verband houden met deze overeenkomst zullen bij uitsluiting voor worden gelegd aan een bevoegde Nederlandse rechtbank.

Voor België

b) Op deze overeenkomst, welke als wettelijk bewijs geldt, is het Belgische recht van toepassing. Geschillen die voortvloeien uit of verband houden met deze overeenkomst zullen bij uitsluiting voor worden gelegd aan een bevoegde Belgische rechtbank.

Na donatie ontvangt u een mail met de tekst van deze overeenkomst en een korte omschrijving van de inhoud van uw donatie.

SoNaR dankt u alvast van harte voor uw bijdrage aan het Referentiecorpus van het hedendaags geschreven Nederlands!